@@ -39,3 +39,25 @@ function filePairDisplayName(filePair) {
 
   return out;
 }
+
+
+/**
+ * Checks whether the diff is one-sided, i.e. an add or delete.
+ */
+function isOneSided(filePair) {
+  return (filePair.type == 'add' || filePair.type == 'delete');
+}
+
+
+// From http://facebook.github.io/react/docs/reusable-components.html
+var SetIntervalMixin = {
+  componentWillMount: function() {
+    this.intervals = [];
+  },
+  setInterval: function() {
+    this.intervals.push(setInterval.apply(null, arguments));
+  },
+  componentWillUnmount: function() {
+    this.intervals.map(clearInterval);
+  }
+};
